HealPixProjection
=================
.. image:: http://img.shields.io/pypi/v/hpproj.svg?text=version
    :target: https://pypi.python.org/pypi/hpproj/
    :alt: Latest release
.. image:: https://git.ias.u-psud.fr/abeelen/hpproj/badges/master/build.svg
    :alt: Master Build
.. image:: https://git.ias.u-psud.fr/abeelen/hpproj/badges/master/coverage.svg
    :alt: Master Coverage
    
HealPixProjection is a project to allow easy and efficient projection of healpix maps onto planar grids.
